/****************************************************************************
** Meta object code from reading C++ file 'kmymoneyselector.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kmymoney-5.2.2/kmymoney/widgets/kmymoneyselector.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kmymoneyselector.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KMyMoneySelectorE_t {};
} // unnamed namespace

template <> constexpr inline auto KMyMoneySelector::qt_create_metaobjectdata<qt_meta_tag_ZN16KMyMoneySelectorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KMyMoneySelector",
        "stateChanged",
        "",
        "itemSelected",
        "id",
        "slotSelectAllItems",
        "slotDeselectAllItems",
        "slotMakeCompletion",
        "exp",
        "txt",
        "slotItemSelected",
        "QTreeWidgetItem*",
        "it_v",
        "slotItemPressed",
        "item",
        "col",
        "selectedItems"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemSelected'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'slotSelectAllItems'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDeselectAllItems'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotMakeCompletion'
        QtMocHelpers::SlotData<int(const QRegularExpression &)>(7, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QRegularExpression, 8 },
        }}),
        // Slot 'slotMakeCompletion'
        QtMocHelpers::SlotData<int(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'slotItemSelected'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *)>(10, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'slotItemPressed'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *, int)>(13, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 11, 14 }, { QMetaType::Int, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'selectedItems'
        QtMocHelpers::PropertyData<QStringList>(16, QMetaType::QStringList, QMC::Readable | QMC::Scriptable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KMyMoneySelector, qt_meta_tag_ZN16KMyMoneySelectorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KMyMoneySelector::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KMyMoneySelectorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KMyMoneySelectorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KMyMoneySelectorE_t>.metaTypes,
    nullptr
} };

void KMyMoneySelector::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KMyMoneySelector *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->stateChanged(); break;
        case 1: _t->itemSelected((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->slotSelectAllItems(); break;
        case 3: _t->slotDeselectAllItems(); break;
        case 4: { int _r = _t->slotMakeCompletion((*reinterpret_cast<std::add_pointer_t<QRegularExpression>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 5: { int _r = _t->slotMakeCompletion((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->slotItemSelected((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1]))); break;
        case 7: _t->slotItemPressed((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KMyMoneySelector::*)()>(_a, &KMyMoneySelector::stateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMyMoneySelector::*)(const QString & )>(_a, &KMyMoneySelector::itemSelected, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->selectedItems(); break;
        default: break;
        }
    }
}

const QMetaObject *KMyMoneySelector::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMyMoneySelector::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KMyMoneySelectorE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KMyMoneySelector::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KMyMoneySelector::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KMyMoneySelector::itemSelected(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
